from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *


class GccInt_IType(IntEnum):
	GccInt_Lin: int = ...
	GccInt_Cir: int = ...
	GccInt_Ell: int = ...
	GccInt_Par: int = ...
	GccInt_Hpr: int = ...
	GccInt_Pnt: int = ...
GccInt_Lin = GccInt_IType.GccInt_Lin
GccInt_Cir = GccInt_IType.GccInt_Cir
GccInt_Ell = GccInt_IType.GccInt_Ell
GccInt_Par = GccInt_IType.GccInt_Par
GccInt_Hpr = GccInt_IType.GccInt_Hpr
GccInt_Pnt = GccInt_IType.GccInt_Pnt

class GccInt_Bisec(Standard_Transient):
	def ArcType(self) -> GccInt_IType: ...
	def Circle(self) -> gp_Circ2d: ...
	def Ellipse(self) -> gp_Elips2d: ...
	def Hyperbola(self) -> gp_Hypr2d: ...
	def Line(self) -> gp_Lin2d: ...
	def Parabola(self) -> gp_Parab2d: ...
	def Point(self) -> gp_Pnt2d: ...

class GccInt_BCirc(GccInt_Bisec):
	def __init__(self, Circ: gp_Circ2d) -> None: ...
	def ArcType(self) -> GccInt_IType: ...
	def Circle(self) -> gp_Circ2d: ...

class GccInt_BElips(GccInt_Bisec):
	def __init__(self, Ellipse: gp_Elips2d) -> None: ...
	def ArcType(self) -> GccInt_IType: ...
	def Ellipse(self) -> gp_Elips2d: ...

class GccInt_BHyper(GccInt_Bisec):
	def __init__(self, Hyper: gp_Hypr2d) -> None: ...
	def ArcType(self) -> GccInt_IType: ...
	def Hyperbola(self) -> gp_Hypr2d: ...

class GccInt_BLine(GccInt_Bisec):
	def __init__(self, Line: gp_Lin2d) -> None: ...
	def ArcType(self) -> GccInt_IType: ...
	def Line(self) -> gp_Lin2d: ...

class GccInt_BParab(GccInt_Bisec):
	def __init__(self, Parab: gp_Parab2d) -> None: ...
	def ArcType(self) -> GccInt_IType: ...
	def Parabola(self) -> gp_Parab2d: ...

class GccInt_BPoint(GccInt_Bisec):
	def __init__(self, Point: gp_Pnt2d) -> None: ...
	def ArcType(self) -> GccInt_IType: ...
	def Point(self) -> gp_Pnt2d: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.Geom import *
from OCC.Core.GeomAdaptor import *
from OCC.Core.Adaptor3d import *


class GeomEvaluator_Curve(Standard_Transient):
	def D0(self, theU: float, theValue: gp_Pnt) -> None: ...
	def D1(self, theU: float, theValue: gp_Pnt, theD1: gp_Vec) -> None: ...
	def D2(self, theU: float, theValue: gp_Pnt, theD1: gp_Vec, theD2: gp_Vec) -> None: ...
	def D3(self, theU: float, theValue: gp_Pnt, theD1: gp_Vec, theD2: gp_Vec, theD3: gp_Vec) -> None: ...
	def DN(self, theU: float, theDerU: int) -> gp_Vec: ...

class GeomEvaluator_Surface(Standard_Transient):
	def D0(self, theU: float, theV: float, theValue: gp_Pnt) -> None: ...
	def D1(self, theU: float, theV: float, theValue: gp_Pnt, theD1U: gp_Vec, theD1V: gp_Vec) -> None: ...
	def D2(self, theU: float, theV: float, theValue: gp_Pnt, theD1U: gp_Vec, theD1V: gp_Vec, theD2U: gp_Vec, theD2V: gp_Vec, theD2UV: gp_Vec) -> None: ...
	def D3(self, theU: float, theV: float, theValue: gp_Pnt, theD1U: gp_Vec, theD1V: gp_Vec, theD2U: gp_Vec, theD2V: gp_Vec, theD2UV: gp_Vec, theD3U: gp_Vec, theD3V: gp_Vec, theD3UUV: gp_Vec, theD3UVV: gp_Vec) -> None: ...
	def DN(self, theU: float, theV: float, theDerU: int, theDerV: int) -> gp_Vec: ...

class GeomEvaluator_OffsetCurve(GeomEvaluator_Curve):
	@overload
	def __init__(self, theBase: Geom_Curve, theOffset: float, theDirection: gp_Dir) -> None: ...
	@overload
	def __init__(self, theBase: GeomAdaptor_HCurve, theOffset: float, theDirection: gp_Dir) -> None: ...
	def D0(self, theU: float, theValue: gp_Pnt) -> None: ...
	def D1(self, theU: float, theValue: gp_Pnt, theD1: gp_Vec) -> None: ...
	def D2(self, theU: float, theValue: gp_Pnt, theD1: gp_Vec, theD2: gp_Vec) -> None: ...
	def D3(self, theU: float, theValue: gp_Pnt, theD1: gp_Vec, theD2: gp_Vec, theD3: gp_Vec) -> None: ...
	def DN(self, theU: float, theDeriv: int) -> gp_Vec: ...
	def SetOffsetDirection(self, theDirection: gp_Dir) -> None: ...
	def SetOffsetValue(self, theOffset: float) -> None: ...

class GeomEvaluator_OffsetSurface(GeomEvaluator_Surface):
	@overload
	def __init__(self, theBase: Geom_Surface, theOffset: float, theOscSurf: Optional[Geom_OsculatingSurface] = Geom_OsculatingSurface()) -> None: ...
	@overload
	def __init__(self, theBase: GeomAdaptor_HSurface, theOffset: float, theOscSurf: Optional[Geom_OsculatingSurface] = Geom_OsculatingSurface()) -> None: ...
	def D0(self, theU: float, theV: float, theValue: gp_Pnt) -> None: ...
	def D1(self, theU: float, theV: float, theValue: gp_Pnt, theD1U: gp_Vec, theD1V: gp_Vec) -> None: ...
	def D2(self, theU: float, theV: float, theValue: gp_Pnt, theD1U: gp_Vec, theD1V: gp_Vec, theD2U: gp_Vec, theD2V: gp_Vec, theD2UV: gp_Vec) -> None: ...
	def D3(self, theU: float, theV: float, theValue: gp_Pnt, theD1U: gp_Vec, theD1V: gp_Vec, theD2U: gp_Vec, theD2V: gp_Vec, theD2UV: gp_Vec, theD3U: gp_Vec, theD3V: gp_Vec, theD3UUV: gp_Vec, theD3UVV: gp_Vec) -> None: ...
	def DN(self, theU: float, theV: float, theDerU: int, theDerV: int) -> gp_Vec: ...
	def SetOffsetValue(self, theOffset: float) -> None: ...

class GeomEvaluator_SurfaceOfExtrusion(GeomEvaluator_Surface):
	@overload
	def __init__(self, theBase: Geom_Curve, theExtrusionDir: gp_Dir) -> None: ...
	@overload
	def __init__(self, theBase: Adaptor3d_HCurve, theExtrusionDir: gp_Dir) -> None: ...
	def D0(self, theU: float, theV: float, theValue: gp_Pnt) -> None: ...
	def D1(self, theU: float, theV: float, theValue: gp_Pnt, theD1U: gp_Vec, theD1V: gp_Vec) -> None: ...
	def D2(self, theU: float, theV: float, theValue: gp_Pnt, theD1U: gp_Vec, theD1V: gp_Vec, theD2U: gp_Vec, theD2V: gp_Vec, theD2UV: gp_Vec) -> None: ...
	def D3(self, theU: float, theV: float, theValue: gp_Pnt, theD1U: gp_Vec, theD1V: gp_Vec, theD2U: gp_Vec, theD2V: gp_Vec, theD2UV: gp_Vec, theD3U: gp_Vec, theD3V: gp_Vec, theD3UUV: gp_Vec, theD3UVV: gp_Vec) -> None: ...
	def DN(self, theU: float, theV: float, theDerU: int, theDerV: int) -> gp_Vec: ...
	def SetDirection(self, theDirection: gp_Dir) -> None: ...

class GeomEvaluator_SurfaceOfRevolution(GeomEvaluator_Surface):
	@overload
	def __init__(self, theBase: Geom_Curve, theRevolDir: gp_Dir, theRevolLoc: gp_Pnt) -> None: ...
	@overload
	def __init__(self, theBase: Adaptor3d_HCurve, theRevolDir: gp_Dir, theRevolLoc: gp_Pnt) -> None: ...
	def D0(self, theU: float, theV: float, theValue: gp_Pnt) -> None: ...
	def D1(self, theU: float, theV: float, theValue: gp_Pnt, theD1U: gp_Vec, theD1V: gp_Vec) -> None: ...
	def D2(self, theU: float, theV: float, theValue: gp_Pnt, theD1U: gp_Vec, theD1V: gp_Vec, theD2U: gp_Vec, theD2V: gp_Vec, theD2UV: gp_Vec) -> None: ...
	def D3(self, theU: float, theV: float, theValue: gp_Pnt, theD1U: gp_Vec, theD1V: gp_Vec, theD2U: gp_Vec, theD2V: gp_Vec, theD2UV: gp_Vec, theD3U: gp_Vec, theD3V: gp_Vec, theD3UUV: gp_Vec, theD3UVV: gp_Vec) -> None: ...
	def DN(self, theU: float, theV: float, theDerU: int, theDerV: int) -> gp_Vec: ...
	def SetAxis(self, theAxis: gp_Ax1) -> None: ...
	def SetDirection(self, theDirection: gp_Dir) -> None: ...
	def SetLocation(self, theLocation: gp_Pnt) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.StepData import *
from OCC.Core.Interface import *
from OCC.Core.StepElement import *


class RWStepElement_RWAnalysisItemWithinRepresentation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_AnalysisItemWithinRepresentation) -> None: ...
	def Share(self, ent: StepElement_AnalysisItemWithinRepresentation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_AnalysisItemWithinRepresentation) -> None: ...

class RWStepElement_RWCurve3dElementDescriptor:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_Curve3dElementDescriptor) -> None: ...
	def Share(self, ent: StepElement_Curve3dElementDescriptor, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_Curve3dElementDescriptor) -> None: ...

class RWStepElement_RWCurveElementEndReleasePacket:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_CurveElementEndReleasePacket) -> None: ...
	def Share(self, ent: StepElement_CurveElementEndReleasePacket, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_CurveElementEndReleasePacket) -> None: ...

class RWStepElement_RWCurveElementSectionDefinition:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_CurveElementSectionDefinition) -> None: ...
	def Share(self, ent: StepElement_CurveElementSectionDefinition, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_CurveElementSectionDefinition) -> None: ...

class RWStepElement_RWCurveElementSectionDerivedDefinitions:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_CurveElementSectionDerivedDefinitions) -> None: ...
	def Share(self, ent: StepElement_CurveElementSectionDerivedDefinitions, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_CurveElementSectionDerivedDefinitions) -> None: ...

class RWStepElement_RWElementDescriptor:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_ElementDescriptor) -> None: ...
	def Share(self, ent: StepElement_ElementDescriptor, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_ElementDescriptor) -> None: ...

class RWStepElement_RWElementMaterial:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_ElementMaterial) -> None: ...
	def Share(self, ent: StepElement_ElementMaterial, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_ElementMaterial) -> None: ...

class RWStepElement_RWSurface3dElementDescriptor:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_Surface3dElementDescriptor) -> None: ...
	def Share(self, ent: StepElement_Surface3dElementDescriptor, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_Surface3dElementDescriptor) -> None: ...

class RWStepElement_RWSurfaceElementProperty:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_SurfaceElementProperty) -> None: ...
	def Share(self, ent: StepElement_SurfaceElementProperty, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_SurfaceElementProperty) -> None: ...

class RWStepElement_RWSurfaceSection:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_SurfaceSection) -> None: ...
	def Share(self, ent: StepElement_SurfaceSection, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_SurfaceSection) -> None: ...

class RWStepElement_RWSurfaceSectionField:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_SurfaceSectionField) -> None: ...
	def Share(self, ent: StepElement_SurfaceSectionField, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_SurfaceSectionField) -> None: ...

class RWStepElement_RWSurfaceSectionFieldConstant:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_SurfaceSectionFieldConstant) -> None: ...
	def Share(self, ent: StepElement_SurfaceSectionFieldConstant, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_SurfaceSectionFieldConstant) -> None: ...

class RWStepElement_RWSurfaceSectionFieldVarying:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_SurfaceSectionFieldVarying) -> None: ...
	def Share(self, ent: StepElement_SurfaceSectionFieldVarying, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_SurfaceSectionFieldVarying) -> None: ...

class RWStepElement_RWUniformSurfaceSection:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_UniformSurfaceSection) -> None: ...
	def Share(self, ent: StepElement_UniformSurfaceSection, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_UniformSurfaceSection) -> None: ...

class RWStepElement_RWVolume3dElementDescriptor:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepElement_Volume3dElementDescriptor) -> None: ...
	def Share(self, ent: StepElement_Volume3dElementDescriptor, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepElement_Volume3dElementDescriptor) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.GeomAbs import *
from OCC.Core.TopTools import *
from OCC.Core.BRepBuilderAPI import *
from OCC.Core.TopOpeBRepBuild import *
from OCC.Core.TopAbs import *
from OCC.Core.Adaptor3d import *
from OCC.Core.gp import *
from OCC.Core.Geom import *


class BRepAlgo_CheckStatus(IntEnum):
	BRepAlgo_OK: int = ...
	BRepAlgo_NOK: int = ...
BRepAlgo_OK = BRepAlgo_CheckStatus.BRepAlgo_OK
BRepAlgo_NOK = BRepAlgo_CheckStatus.BRepAlgo_NOK

class brepalgo:
	@staticmethod
	def ConcatenateWire(Wire: TopoDS_Wire, Option: GeomAbs_Shape, AngularTolerance: Optional[float] = 1.0e-4) -> TopoDS_Wire: ...
	@staticmethod
	def ConcatenateWireC0(Wire: TopoDS_Wire) -> TopoDS_Edge: ...
	@staticmethod
	def IsTopologicallyValid(S: TopoDS_Shape) -> bool: ...
	@overload
	@staticmethod
	def IsValid(S: TopoDS_Shape) -> bool: ...
	@overload
	@staticmethod
	def IsValid(theArgs: TopTools_ListOfShape, theResult: TopoDS_Shape, closedSolid: Optional[bool] = False, GeomCtrl: Optional[bool] = True) -> bool: ...

class BRepAlgo_AsDes(Standard_Transient):
	def __init__(self) -> None: ...
	@overload
	def Add(self, S: TopoDS_Shape, SS: TopoDS_Shape) -> None: ...
	@overload
	def Add(self, S: TopoDS_Shape, SS: TopTools_ListOfShape) -> None: ...
	def Ascendant(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def ChangeDescendant(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def Clear(self) -> None: ...
	def Descendant(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def HasAscendant(self, S: TopoDS_Shape) -> bool: ...
	def HasCommonDescendant(self, S1: TopoDS_Shape, S2: TopoDS_Shape, LC: TopTools_ListOfShape) -> bool: ...
	def HasDescendant(self, S: TopoDS_Shape) -> bool: ...
	def Remove(self, S: TopoDS_Shape) -> None: ...
	def Replace(self, OldS: TopoDS_Shape, NewS: TopoDS_Shape) -> None: ...

class BRepAlgo_BooleanOperation(BRepBuilderAPI_MakeShape):
	def Builder(self) -> TopOpeBRepBuild_HBuilder: ...
	def IsDeleted(self, S: TopoDS_Shape) -> bool: ...
	def Modified(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def Perform(self, St1: TopAbs_State, St2: TopAbs_State) -> None: ...
	def PerformDS(self) -> None: ...
	def Shape1(self) -> TopoDS_Shape: ...
	def Shape2(self) -> TopoDS_Shape: ...

class BRepAlgo_FaceRestrictor:
	def __init__(self) -> None: ...
	def Add(self, W: TopoDS_Wire) -> None: ...
	def Clear(self) -> None: ...
	def Current(self) -> TopoDS_Face: ...
	def Init(self, F: TopoDS_Face, Proj: Optional[bool] = False, ControlOrientation: Optional[bool] = False) -> None: ...
	def IsDone(self) -> bool: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Perform(self) -> None: ...

class BRepAlgo_Image:
	def __init__(self) -> None: ...
	@overload
	def Add(self, OldS: TopoDS_Shape, NewS: TopoDS_Shape) -> None: ...
	@overload
	def Add(self, OldS: TopoDS_Shape, NewS: TopTools_ListOfShape) -> None: ...
	@overload
	def Bind(self, OldS: TopoDS_Shape, NewS: TopoDS_Shape) -> None: ...
	@overload
	def Bind(self, OldS: TopoDS_Shape, NewS: TopTools_ListOfShape) -> None: ...
	def Clear(self) -> None: ...
	def Compact(self) -> None: ...
	def Filter(self, S: TopoDS_Shape, ShapeType: TopAbs_ShapeEnum) -> None: ...
	def HasImage(self, S: TopoDS_Shape) -> bool: ...
	def Image(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def ImageFrom(self, S: TopoDS_Shape) -> TopoDS_Shape: ...
	def IsImage(self, S: TopoDS_Shape) -> bool: ...
	def LastImage(self, S: TopoDS_Shape, L: TopTools_ListOfShape) -> None: ...
	def Remove(self, S: TopoDS_Shape) -> None: ...
	def RemoveRoot(self, Root: TopoDS_Shape) -> None: ...
	def ReplaceRoot(self, OldRoot: TopoDS_Shape, NewRoot: TopoDS_Shape) -> None: ...
	def Root(self, S: TopoDS_Shape) -> TopoDS_Shape: ...
	def Roots(self) -> TopTools_ListOfShape: ...
	def SetRoot(self, S: TopoDS_Shape) -> None: ...

class BRepAlgo_Loop:
	def __init__(self) -> None: ...
	def AddConstEdge(self, E: TopoDS_Edge) -> None: ...
	def AddConstEdges(self, LE: TopTools_ListOfShape) -> None: ...
	def AddEdge(self, E: TopoDS_Edge, LV: TopTools_ListOfShape) -> None: ...
	def CutEdge(self, E: TopoDS_Edge, VonE: TopTools_ListOfShape, NE: TopTools_ListOfShape) -> None: ...
	def GetVerticesForSubstitute(self, VerVerMap: TopTools_DataMapOfShapeShape) -> None: ...
	def Init(self, F: TopoDS_Face) -> None: ...
	def NewEdges(self, E: TopoDS_Edge) -> TopTools_ListOfShape: ...
	def NewFaces(self) -> TopTools_ListOfShape: ...
	def NewWires(self) -> TopTools_ListOfShape: ...
	def Perform(self) -> None: ...
	def VerticesForSubstitute(self, VerVerMap: TopTools_DataMapOfShapeShape) -> None: ...
	def WiresToFaces(self) -> None: ...

class BRepAlgo_NormalProjection:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape) -> None: ...
	def Add(self, ToProj: TopoDS_Shape) -> None: ...
	def Ancestor(self, E: TopoDS_Edge) -> TopoDS_Shape: ...
	def Build(self) -> None: ...
	def BuildWire(self, Liste: TopTools_ListOfShape) -> bool: ...
	def Compute3d(self, With3d: Optional[bool] = True) -> None: ...
	def Couple(self, E: TopoDS_Edge) -> TopoDS_Shape: ...
	def Generated(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def Init(self, S: TopoDS_Shape) -> None: ...
	def IsDone(self) -> bool: ...
	def IsElementary(self, C: Adaptor3d_Curve) -> bool: ...
	def Projection(self) -> TopoDS_Shape: ...
	def SetDefaultParams(self) -> None: ...
	def SetLimit(self, FaceBoundaries: Optional[bool] = True) -> None: ...
	def SetMaxDistance(self, MaxDist: float) -> None: ...
	def SetParams(self, Tol3D: float, Tol2D: float, InternalContinuity: GeomAbs_Shape, MaxDegree: int, MaxSeg: int) -> None: ...

class BRepAlgo_Tool:
	@staticmethod
	def Deboucle3D(S: TopoDS_Shape, Boundary: TopTools_MapOfShape) -> TopoDS_Shape: ...

class BRepAlgo_Common(BRepAlgo_BooleanOperation):
	def __init__(self, S1: TopoDS_Shape, S2: TopoDS_Shape) -> None: ...

class BRepAlgo_Cut(BRepAlgo_BooleanOperation):
	def __init__(self, S1: TopoDS_Shape, S2: TopoDS_Shape) -> None: ...

class BRepAlgo_Fuse(BRepAlgo_BooleanOperation):
	def __init__(self, S1: TopoDS_Shape, S2: TopoDS_Shape) -> None: ...

class BRepAlgo_Section(BRepAlgo_BooleanOperation):
	@overload
	def __init__(self, Sh1: TopoDS_Shape, Sh2: TopoDS_Shape, PerformNow: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Sh: TopoDS_Shape, Pl: gp_Pln, PerformNow: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Sh: TopoDS_Shape, Sf: Geom_Surface, PerformNow: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Sf: Geom_Surface, Sh: TopoDS_Shape, PerformNow: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Sf1: Geom_Surface, Sf2: Geom_Surface, PerformNow: Optional[bool] = True) -> None: ...
	def Approximation(self, B: bool) -> None: ...
	def Build(self) -> None: ...
	def ComputePCurveOn1(self, B: bool) -> None: ...
	def ComputePCurveOn2(self, B: bool) -> None: ...
	def HasAncestorFaceOn1(self, E: TopoDS_Shape, F: TopoDS_Shape) -> bool: ...
	def HasAncestorFaceOn2(self, E: TopoDS_Shape, F: TopoDS_Shape) -> bool: ...
	@overload
	def Init1(self, S1: TopoDS_Shape) -> None: ...
	@overload
	def Init1(self, Pl: gp_Pln) -> None: ...
	@overload
	def Init1(self, Sf: Geom_Surface) -> None: ...
	@overload
	def Init2(self, S2: TopoDS_Shape) -> None: ...
	@overload
	def Init2(self, Pl: gp_Pln) -> None: ...
	@overload
	def Init2(self, Sf: Geom_Surface) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

brepalgo_ConcatenateWire = brepalgo.ConcatenateWire
brepalgo_ConcatenateWireC0 = brepalgo.ConcatenateWireC0
brepalgo_IsTopologicallyValid = brepalgo.IsTopologicallyValid
brepalgo_IsValid = brepalgo.IsValid
brepalgo_IsValid = brepalgo.IsValid
BRepAlgo_Tool_Deboucle3D = BRepAlgo_Tool.Deboucle3D



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BRepIntCurveSurface module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_brepintcurvesurface.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BRepIntCurveSurface
else:
    import _BRepIntCurveSurface

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BRepIntCurveSurface.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BRepIntCurveSurface.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepIntCurveSurface.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepIntCurveSurface.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BRepIntCurveSurface.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BRepIntCurveSurface.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BRepIntCurveSurface.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BRepIntCurveSurface.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BRepIntCurveSurface.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BRepIntCurveSurface.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepIntCurveSurface.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BRepIntCurveSurface.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BRepIntCurveSurface.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepIntCurveSurface.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepIntCurveSurface.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepIntCurveSurface.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BRepIntCurveSurface.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BRepIntCurveSurface:
_BRepIntCurveSurface.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BRepIntCurveSurface.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.GeomAdaptor
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.IntCurveSurface
import OCC.Core.Intf
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.IntSurf

from enum import IntEnum
from OCC.Core.Exception import *



class BRepIntCurveSurface_Inter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor;.

        Returns
        -------
        None

        """
        _BRepIntCurveSurface.BRepIntCurveSurface_Inter_swiginit(self, _BRepIntCurveSurface.new_BRepIntCurveSurface_Inter(*args))

    def Face(self, *args) -> "TopoDS_Face const":
        r"""
        Returns the current face.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepIntCurveSurface.BRepIntCurveSurface_Inter_Face(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Load the shape, the curve and initialize the tolerance used for the classification.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theCurve: GeomAdaptor_Curve
        theTol: float

        Returns
        -------
        None
        Load the shape, the curve and initialize the tolerance used for the classification.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theLine: gp_Lin
        theTol: float

        Returns
        -------
        None
        Method to find intersections of specified curve with loaded shape.

        Parameters
        ----------
        theCurve: GeomAdaptor_Curve

        Returns
        -------
        None

        """
        return _BRepIntCurveSurface.BRepIntCurveSurface_Inter_Init(self, *args)

    def Load(self, *args) -> "void":
        r"""
        Load the shape, and initialize the tolerance used for the classification.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theTol: float

        Returns
        -------
        None

        """
        return _BRepIntCurveSurface.BRepIntCurveSurface_Inter_Load(self, *args)

    def More(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if there is a current face.

        Returns
        -------
        bool

        """
        return _BRepIntCurveSurface.BRepIntCurveSurface_Inter_More(self, *args)

    def Next(self, *args) -> "void":
        r"""
        Sets the next intersection point to check.

        Returns
        -------
        None

        """
        return _BRepIntCurveSurface.BRepIntCurveSurface_Inter_Next(self, *args)

    def Pnt(self, *args) -> "gp_Pnt const":
        r"""
        Returns the current geometric point.

        Returns
        -------
        gp_Pnt

        """
        return _BRepIntCurveSurface.BRepIntCurveSurface_Inter_Pnt(self, *args)

    def Point(self, *args) -> "IntCurveSurface_IntersectionPoint":
        r"""
        Returns the current intersection point.

        Returns
        -------
        IntCurveSurface_IntersectionPoint

        """
        return _BRepIntCurveSurface.BRepIntCurveSurface_Inter_Point(self, *args)

    def State(self, *args) -> "TopAbs_State":
        r"""
        Returns the current state (in or on).

        Returns
        -------
        TopAbs_State

        """
        return _BRepIntCurveSurface.BRepIntCurveSurface_Inter_State(self, *args)

    def Transition(self, *args) -> "IntCurveSurface_TransitionOnCurve":
        r"""
        Returns the transition of the line on the surface (in or out or unknown).

        Returns
        -------
        IntCurveSurface_TransitionOnCurve

        """
        return _BRepIntCurveSurface.BRepIntCurveSurface_Inter_Transition(self, *args)

    def U(self, *args) -> "Standard_Real":
        r"""
        Returns the u parameter of the current point on the current face.

        Returns
        -------
        float

        """
        return _BRepIntCurveSurface.BRepIntCurveSurface_Inter_U(self, *args)

    def V(self, *args) -> "Standard_Real":
        r"""
        Returns the v parameter of the current point on the current face.

        Returns
        -------
        float

        """
        return _BRepIntCurveSurface.BRepIntCurveSurface_Inter_V(self, *args)

    def W(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter of the current point on the curve.

        Returns
        -------
        float

        """
        return _BRepIntCurveSurface.BRepIntCurveSurface_Inter_W(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepIntCurveSurface.delete_BRepIntCurveSurface_Inter

# Register BRepIntCurveSurface_Inter in _BRepIntCurveSurface:
_BRepIntCurveSurface.BRepIntCurveSurface_Inter_swigregister(BRepIntCurveSurface_Inter)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.Bnd import *
from OCC.Core.Adaptor2d import *
from OCC.Core.Geom2d import *
from OCC.Core.Adaptor3d import *


class bndlib:
	@overload
	@staticmethod
	def Add(L: gp_Lin, P1: float, P2: float, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(L: gp_Lin2d, P1: float, P2: float, Tol: float, B: Bnd_Box2d) -> None: ...
	@overload
	@staticmethod
	def Add(C: gp_Circ, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(C: gp_Circ, P1: float, P2: float, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(C: gp_Circ2d, Tol: float, B: Bnd_Box2d) -> None: ...
	@overload
	@staticmethod
	def Add(C: gp_Circ2d, P1: float, P2: float, Tol: float, B: Bnd_Box2d) -> None: ...
	@overload
	@staticmethod
	def Add(C: gp_Elips, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(C: gp_Elips, P1: float, P2: float, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(C: gp_Elips2d, Tol: float, B: Bnd_Box2d) -> None: ...
	@overload
	@staticmethod
	def Add(C: gp_Elips2d, P1: float, P2: float, Tol: float, B: Bnd_Box2d) -> None: ...
	@overload
	@staticmethod
	def Add(P: gp_Parab, P1: float, P2: float, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(P: gp_Parab2d, P1: float, P2: float, Tol: float, B: Bnd_Box2d) -> None: ...
	@overload
	@staticmethod
	def Add(H: gp_Hypr, P1: float, P2: float, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(H: gp_Hypr2d, P1: float, P2: float, Tol: float, B: Bnd_Box2d) -> None: ...
	@overload
	@staticmethod
	def Add(S: gp_Cylinder, UMin: float, UMax: float, VMin: float, VMax: float, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(S: gp_Cylinder, VMin: float, VMax: float, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(S: gp_Cone, UMin: float, UMax: float, VMin: float, VMax: float, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(S: gp_Cone, VMin: float, VMax: float, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(S: gp_Sphere, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(S: gp_Sphere, UMin: float, UMax: float, VMin: float, VMax: float, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(P: gp_Torus, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(P: gp_Torus, UMin: float, UMax: float, VMin: float, VMax: float, Tol: float, B: Bnd_Box) -> None: ...

class BndLib_Add2dCurve:
	@overload
	@staticmethod
	def Add(C: Adaptor2d_Curve2d, Tol: float, B: Bnd_Box2d) -> None: ...
	@overload
	@staticmethod
	def Add(C: Adaptor2d_Curve2d, U1: float, U2: float, Tol: float, B: Bnd_Box2d) -> None: ...
	@overload
	@staticmethod
	def Add(C: Geom2d_Curve, Tol: float, Box: Bnd_Box2d) -> None: ...
	@overload
	@staticmethod
	def Add(C: Geom2d_Curve, U1: float, U2: float, Tol: float, B: Bnd_Box2d) -> None: ...
	@staticmethod
	def AddOptimal(C: Geom2d_Curve, U1: float, U2: float, Tol: float, B: Bnd_Box2d) -> None: ...

class BndLib_Add3dCurve:
	@overload
	@staticmethod
	def Add(C: Adaptor3d_Curve, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(C: Adaptor3d_Curve, U1: float, U2: float, Tol: float, B: Bnd_Box) -> None: ...
	@staticmethod
	def AddGenCurv(C: Adaptor3d_Curve, UMin: float, UMax: float, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def AddOptimal(C: Adaptor3d_Curve, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def AddOptimal(C: Adaptor3d_Curve, U1: float, U2: float, Tol: float, B: Bnd_Box) -> None: ...

class BndLib_AddSurface:
	@overload
	@staticmethod
	def Add(S: Adaptor3d_Surface, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def Add(S: Adaptor3d_Surface, UMin: float, UMax: float, VMin: float, VMax: float, Tol: float, B: Bnd_Box) -> None: ...
	@staticmethod
	def AddGenSurf(S: Adaptor3d_Surface, UMin: float, UMax: float, VMin: float, VMax: float, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def AddOptimal(S: Adaptor3d_Surface, Tol: float, B: Bnd_Box) -> None: ...
	@overload
	@staticmethod
	def AddOptimal(S: Adaptor3d_Surface, UMin: float, UMax: float, VMin: float, VMax: float, Tol: float, B: Bnd_Box) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
bndlib_Add = bndlib.Add
BndLib_Add2dCurve_Add = BndLib_Add2dCurve.Add
BndLib_Add2dCurve_Add = BndLib_Add2dCurve.Add
BndLib_Add2dCurve_Add = BndLib_Add2dCurve.Add
BndLib_Add2dCurve_Add = BndLib_Add2dCurve.Add
BndLib_Add2dCurve_AddOptimal = BndLib_Add2dCurve.AddOptimal
BndLib_Add3dCurve_Add = BndLib_Add3dCurve.Add
BndLib_Add3dCurve_Add = BndLib_Add3dCurve.Add
BndLib_Add3dCurve_AddGenCurv = BndLib_Add3dCurve.AddGenCurv
BndLib_Add3dCurve_AddOptimal = BndLib_Add3dCurve.AddOptimal
BndLib_Add3dCurve_AddOptimal = BndLib_Add3dCurve.AddOptimal
BndLib_AddSurface_Add = BndLib_AddSurface.Add
BndLib_AddSurface_Add = BndLib_AddSurface.Add
BndLib_AddSurface_AddGenSurf = BndLib_AddSurface.AddGenSurf
BndLib_AddSurface_AddOptimal = BndLib_AddSurface.AddOptimal
BndLib_AddSurface_AddOptimal = BndLib_AddSurface.AddOptimal



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.Message import *
from OCC.Core.Geom2d import *
from OCC.Core.Geom import *
from OCC.Core.TopLoc import *
from OCC.Core.TopAbs import *

BinTools_LocationSetPtr = NewType('BinTools_LocationSetPtr', BinTools_LocationSet)

class bintools:
	@overload
	@staticmethod
	def Read(theShape: TopoDS_Shape, theFile: str, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> bool: ...
	@overload
	@staticmethod
	def Write(theShape: TopoDS_Shape, theFile: str, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> bool: ...

class BinTools_Curve2dSet:
	def __init__(self) -> None: ...
	def Add(self, C: Geom2d_Curve) -> int: ...
	def Clear(self) -> None: ...
	def Curve2d(self, I: int) -> Geom2d_Curve: ...
	def Index(self, C: Geom2d_Curve) -> int: ...

class BinTools_CurveSet:
	def __init__(self) -> None: ...
	def Add(self, C: Geom_Curve) -> int: ...
	def Clear(self) -> None: ...
	def Curve(self, I: int) -> Geom_Curve: ...
	def Index(self, C: Geom_Curve) -> int: ...

class BinTools_LocationSet:
	def __init__(self) -> None: ...
	def Add(self, L: TopLoc_Location) -> int: ...
	def Clear(self) -> None: ...
	def Index(self, L: TopLoc_Location) -> int: ...
	def Location(self, I: int) -> TopLoc_Location: ...
	def NbLocations(self) -> int: ...

class BinTools_ShapeSet:
	def __init__(self, isWithTriangles: Optional[bool] = False) -> None: ...
	def Add(self, S: TopoDS_Shape) -> int: ...
	def AddGeometry(self, S: TopoDS_Shape) -> None: ...
	def AddShapes(self, S1: TopoDS_Shape, S2: TopoDS_Shape) -> None: ...
	def ChangeLocations(self) -> BinTools_LocationSet: ...
	def Clear(self) -> None: ...
	def FormatNb(self) -> int: ...
	def Index(self, S: TopoDS_Shape) -> int: ...
	def IsWithTriangles(self) -> bool: ...
	def Locations(self) -> BinTools_LocationSet: ...
	def NbShapes(self) -> int: ...
	def SetFormatNb(self, theFormatNb: int) -> None: ...
	def SetWithTriangles(self, isWithTriangles: bool) -> None: ...
	def Shape(self, I: int) -> TopoDS_Shape: ...

class BinTools_SurfaceSet:
	def __init__(self) -> None: ...
	def Add(self, S: Geom_Surface) -> int: ...
	def Clear(self) -> None: ...
	def Index(self, S: Geom_Surface) -> int: ...
	def Surface(self, I: int) -> Geom_Surface: ...

# harray1 classes
# harray2 classes
# hsequence classes

bintools_GetBool = bintools.GetBool
bintools_GetExtChar = bintools.GetExtChar
bintools_GetInteger = bintools.GetInteger
bintools_GetReal = bintools.GetReal
bintools_GetShortReal = bintools.GetShortReal
bintools_PutBool = bintools.PutBool
bintools_PutExtChar = bintools.PutExtChar
bintools_PutInteger = bintools.PutInteger
bintools_PutReal = bintools.PutReal
bintools_PutShortReal = bintools.PutShortReal
bintools_Read = bintools.Read
bintools_Read = bintools.Read
bintools_Write = bintools.Write
bintools_Write = bintools.Write
BinTools_Curve2dSet_ReadCurve2d = BinTools_Curve2dSet.ReadCurve2d
BinTools_Curve2dSet_WriteCurve2d = BinTools_Curve2dSet.WriteCurve2d
BinTools_CurveSet_ReadCurve = BinTools_CurveSet.ReadCurve
BinTools_CurveSet_WriteCurve = BinTools_CurveSet.WriteCurve
BinTools_SurfaceSet_ReadSurface = BinTools_SurfaceSet.ReadSurface
BinTools_SurfaceSet_WriteSurface = BinTools_SurfaceSet.WriteSurface



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
RWObj module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_rwobj.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _RWObj
else:
    import _RWObj

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _RWObj.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _RWObj.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWObj.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWObj.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _RWObj.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _RWObj.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _RWObj.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _RWObj.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _RWObj.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _RWObj.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWObj.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _RWObj.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _RWObj.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWObj.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWObj.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWObj.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _RWObj.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _RWObj:
_RWObj.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _RWObj.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.Poly
import OCC.Core.gp
import OCC.Core.TColgp
import OCC.Core.TShort
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.Graphic3d
import OCC.Core.BVH
import OCC.Core.Quantity
import OCC.Core.Aspect
import OCC.Core.Image
import OCC.Core.Bnd
import OCC.Core.Media

from enum import IntEnum
from OCC.Core.Exception import *

RWObj_SubMeshReason_NewObject = _RWObj.RWObj_SubMeshReason_NewObject
RWObj_SubMeshReason_NewGroup = _RWObj.RWObj_SubMeshReason_NewGroup
RWObj_SubMeshReason_NewMaterial = _RWObj.RWObj_SubMeshReason_NewMaterial
RWObj_SubMeshReason_NewSmoothGroup = _RWObj.RWObj_SubMeshReason_NewSmoothGroup


class RWObj_SubMeshReason(IntEnum):
	RWObj_SubMeshReason_NewObject = 0
	RWObj_SubMeshReason_NewGroup = 1
	RWObj_SubMeshReason_NewMaterial = 2
	RWObj_SubMeshReason_NewSmoothGroup = 3
RWObj_SubMeshReason_NewObject = RWObj_SubMeshReason.RWObj_SubMeshReason_NewObject
RWObj_SubMeshReason_NewGroup = RWObj_SubMeshReason.RWObj_SubMeshReason_NewGroup
RWObj_SubMeshReason_NewMaterial = RWObj_SubMeshReason.RWObj_SubMeshReason_NewMaterial
RWObj_SubMeshReason_NewSmoothGroup = RWObj_SubMeshReason.RWObj_SubMeshReason_NewSmoothGroup


def Handle_RWObj_Reader_Create() -> "opencascade::handle< RWObj_Reader >":
    return _RWObj.Handle_RWObj_Reader_Create()

def Handle_RWObj_Reader_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< RWObj_Reader >":
    return _RWObj.Handle_RWObj_Reader_DownCast(t)

def Handle_RWObj_Reader_IsNull(t: "opencascade::handle< RWObj_Reader > const &") -> "bool":
    return _RWObj.Handle_RWObj_Reader_IsNull(t)

def Handle_RWObj_TriangulationReader_Create() -> "opencascade::handle< RWObj_TriangulationReader >":
    return _RWObj.Handle_RWObj_TriangulationReader_Create()

def Handle_RWObj_TriangulationReader_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< RWObj_TriangulationReader >":
    return _RWObj.Handle_RWObj_TriangulationReader_DownCast(t)

def Handle_RWObj_TriangulationReader_IsNull(t: "opencascade::handle< RWObj_TriangulationReader > const &") -> "bool":
    return _RWObj.Handle_RWObj_TriangulationReader_IsNull(t)
class rwobj(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def ReadFile(*args) -> "opencascade::handle< Poly_Triangulation >":
        r"""
        Read specified obj file and returns its content as triangulation. in case of error, returns null handle.

        Parameters
        ----------
        theFile: char *
        aProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        opencascade::handle<Poly_Triangulation>

        """
        return _RWObj.rwobj_ReadFile(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _RWObj.rwobj_swiginit(self, _RWObj.new_rwobj())
    __swig_destroy__ = _RWObj.delete_rwobj

# Register rwobj in _RWObj:
_RWObj.rwobj_swigregister(rwobj)

def rwobj_ReadFile(*args) -> "opencascade::handle< Poly_Triangulation >":
    r"""
    Read specified obj file and returns its content as triangulation. in case of error, returns null handle.

    Parameters
    ----------
    theFile: char *
    aProgress: Message_ProgressRange,optional
    	default value is Message_ProgressRange()

    Returns
    -------
    opencascade::handle<Poly_Triangulation>

    """
    return _RWObj.rwobj_ReadFile(*args)

class RWObj_IShapeReceiver(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def BindNamedShape(self, *args) -> "void":
        r"""
        @param theshape shape to register @param thename shape name @param thematerial shape material @param theisrootshape indicates that this is a root object (free shape).

        Parameters
        ----------
        theShape: TopoDS_Shape
        theName: TCollection_AsciiString
        theMaterial: RWObj_Material *
        theIsRootShape: bool

        Returns
        -------
        None

        """
        return _RWObj.RWObj_IShapeReceiver_BindNamedShape(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWObj.delete_RWObj_IShapeReceiver

# Register RWObj_IShapeReceiver in _RWObj:
_RWObj.RWObj_IShapeReceiver_swigregister(RWObj_IShapeReceiver)

class RWObj_Material(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    Name = property(_RWObj.RWObj_Material_Name_get, _RWObj.RWObj_Material_Name_set)
    DiffuseTexture = property(_RWObj.RWObj_Material_DiffuseTexture_get, _RWObj.RWObj_Material_DiffuseTexture_set)
    SpecularTexture = property(_RWObj.RWObj_Material_SpecularTexture_get, _RWObj.RWObj_Material_SpecularTexture_set)
    BumpTexture = property(_RWObj.RWObj_Material_BumpTexture_get, _RWObj.RWObj_Material_BumpTexture_set)
    AmbientColor = property(_RWObj.RWObj_Material_AmbientColor_get, _RWObj.RWObj_Material_AmbientColor_set)
    DiffuseColor = property(_RWObj.RWObj_Material_DiffuseColor_get, _RWObj.RWObj_Material_DiffuseColor_set)
    SpecularColor = property(_RWObj.RWObj_Material_SpecularColor_get, _RWObj.RWObj_Material_SpecularColor_set)
    Shininess = property(_RWObj.RWObj_Material_Shininess_get, _RWObj.RWObj_Material_Shininess_set)
    Transparency = property(_RWObj.RWObj_Material_Transparency_get, _RWObj.RWObj_Material_Transparency_set)

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWObj.RWObj_Material_swiginit(self, _RWObj.new_RWObj_Material(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _RWObj.delete_RWObj_Material

# Register RWObj_Material in _RWObj:
_RWObj.RWObj_Material_swigregister(RWObj_Material)

class RWObj_Reader(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def ExternalFiles(self, *args) -> "NCollection_IndexedMap< TCollection_AsciiString > const &":
        r"""
        Return the list of external file references.

        Returns
        -------
        NCollection_IndexedMap<TCollection_AsciiString>

        """
        return _RWObj.RWObj_Reader_ExternalFiles(self, *args)

    def FileComments(self, *args) -> "TCollection_AsciiString const &":
        r"""
        Returns file comments (lines starting with # at the beginning of file).

        Returns
        -------
        TCollection_AsciiString

        """
        return _RWObj.RWObj_Reader_FileComments(self, *args)

    def IsSinglePrecision(self, *args) -> "Standard_Boolean":
        r"""
        Return single precision flag for reading vertex data (coordinates); false by default.

        Returns
        -------
        bool

        """
        return _RWObj.RWObj_Reader_IsSinglePrecision(self, *args)

    def MemoryLimit(self, *args) -> "Standard_Size":
        r"""
        Returns memory limit in bytes; -1 (no limit) by default.

        Returns
        -------
        Standard_Size

        """
        return _RWObj.RWObj_Reader_MemoryLimit(self, *args)

    def NbProbeElems(self, *args) -> "Standard_Integer":
        r"""
        //!< number of probed polygon elements (of unknown size).

        Returns
        -------
        int

        """
        return _RWObj.RWObj_Reader_NbProbeElems(self, *args)

    def NbProbeNodes(self, *args) -> "Standard_Integer":
        r"""
        Number of probed nodes.

        Returns
        -------
        int

        """
        return _RWObj.RWObj_Reader_NbProbeNodes(self, *args)

    def Probe(self, *args) -> "Standard_Boolean":
        r"""
        Probe data from obj file (comments, external references) without actually reading mesh data. although mesh data will not be collected, the full file content will be parsed, due to obj format limitations. @param thefile path to the file @param theprogress progress indicator returns true if success, false on error or user break. @sa filecomments(), externalfiles(), nbprobenodes(), nbprobeelems().

        Parameters
        ----------
        theFile: TCollection_AsciiString
        theProgress: Message_ProgressRange

        Returns
        -------
        bool

        """
        return _RWObj.RWObj_Reader_Probe(self, *args)

    def Read(self, *args) -> "Standard_Boolean":
        r"""
        Reads data from obj file. unicode paths can be given in utf-8 encoding. returns true if success, false on error or user break.

        Parameters
        ----------
        theFile: TCollection_AsciiString
        theProgress: Message_ProgressRange

        Returns
        -------
        bool

        """
        return _RWObj.RWObj_Reader_Read(self, *args)

    def SetMemoryLimit(self, *args) -> "void":
        r"""
        Specify memory limit in bytes, so that import will be aborted by specified limit before memory allocation error occurs.

        Parameters
        ----------
        theMemLimit: Standard_Size

        Returns
        -------
        None

        """
        return _RWObj.RWObj_Reader_SetMemoryLimit(self, *args)

    def SetSinglePrecision(self, *args) -> "void":
        r"""
        Setup single/double precision flag for reading vertex data (coordinates).

        Parameters
        ----------
        theIsSinglePrecision: bool

        Returns
        -------
        None

        """
        return _RWObj.RWObj_Reader_SetSinglePrecision(self, *args)

    def SetTransformation(self, *args) -> "void":
        r"""
        Setup transformation from one coordinate system to another. obj file might be exported following various coordinate system conventions, so that it might be useful automatically transform data during file reading.

        Parameters
        ----------
        theCSConverter: RWMesh_CoordinateSystemConverter

        Returns
        -------
        None

        """
        return _RWObj.RWObj_Reader_SetTransformation(self, *args)

    def Transformation(self, *args) -> "RWMesh_CoordinateSystemConverter const &":
        r"""
        Return transformation from one coordinate system to another; no transformation by default.

        Returns
        -------
        RWMesh_CoordinateSystemConverter

        """
        return _RWObj.RWObj_Reader_Transformation(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_RWObj_Reader_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _RWObj.delete_RWObj_Reader

# Register RWObj_Reader in _RWObj:
_RWObj.RWObj_Reader_swigregister(RWObj_Reader)

class RWObj_SubMesh(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    Object = property(_RWObj.RWObj_SubMesh_Object_get, _RWObj.RWObj_SubMesh_Object_set)
    Group = property(_RWObj.RWObj_SubMesh_Group_get, _RWObj.RWObj_SubMesh_Group_set)
    SmoothGroup = property(_RWObj.RWObj_SubMesh_SmoothGroup_get, _RWObj.RWObj_SubMesh_SmoothGroup_set)
    Material = property(_RWObj.RWObj_SubMesh_Material_get, _RWObj.RWObj_SubMesh_Material_set)

    __repr__ = _dumps_object


    def __init__(self):
        _RWObj.RWObj_SubMesh_swiginit(self, _RWObj.new_RWObj_SubMesh())
    __swig_destroy__ = _RWObj.delete_RWObj_SubMesh

# Register RWObj_SubMesh in _RWObj:
_RWObj.RWObj_SubMesh_swigregister(RWObj_SubMesh)

class RWObj_CafReader(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWObj.RWObj_CafReader_swiginit(self, _RWObj.new_RWObj_CafReader(*args))

    def IsSinglePrecision(self, *args) -> "Standard_Boolean":
        r"""
        Return single precision flag for reading vertex data (coordinates); false by default.

        Returns
        -------
        bool

        """
        return _RWObj.RWObj_CafReader_IsSinglePrecision(self, *args)

    def SetSinglePrecision(self, *args) -> "void":
        r"""
        Setup single/double precision flag for reading vertex data (coordinates).

        Parameters
        ----------
        theIsSinglePrecision: bool

        Returns
        -------
        None

        """
        return _RWObj.RWObj_CafReader_SetSinglePrecision(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWObj.delete_RWObj_CafReader

# Register RWObj_CafReader in _RWObj:
_RWObj.RWObj_CafReader_swigregister(RWObj_CafReader)

class RWObj_TriangulationReader(RWObj_Reader):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructor.

        Returns
        -------
        None

        """
        _RWObj.RWObj_TriangulationReader_swiginit(self, _RWObj.new_RWObj_TriangulationReader(*args))

    def GetTriangulation(self, *args) -> "opencascade::handle< Poly_Triangulation >":
        r"""
        Create poly_triangulation from collected data.

        Returns
        -------
        opencascade::handle<Poly_Triangulation>

        """
        return _RWObj.RWObj_TriangulationReader_GetTriangulation(self, *args)

    def ResultShape(self, *args) -> "TopoDS_Shape":
        r"""
        Return result shape.

        Returns
        -------
        TopoDS_Shape

        """
        return _RWObj.RWObj_TriangulationReader_ResultShape(self, *args)

    def SetCreateShapes(self, *args) -> "void":
        r"""
        Set flag to create shapes.

        Parameters
        ----------
        theToCreateShapes: bool

        Returns
        -------
        None

        """
        return _RWObj.RWObj_TriangulationReader_SetCreateShapes(self, *args)

    def SetShapeReceiver(self, *args) -> "void":
        r"""
        Set shape receiver callback.

        Parameters
        ----------
        theReceiver: RWObj_IShapeReceiver *

        Returns
        -------
        None

        """
        return _RWObj.RWObj_TriangulationReader_SetShapeReceiver(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_RWObj_TriangulationReader_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _RWObj.delete_RWObj_TriangulationReader

# Register RWObj_TriangulationReader in _RWObj:
_RWObj.RWObj_TriangulationReader_swigregister(RWObj_TriangulationReader)


@classnotwrapped
class RWObj_MtlReader:
	pass









from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.BRepTopAdaptor import *
from OCC.Core.IntRes2d import *
from OCC.Core.IntSurf import *
from OCC.Core.IntPatch import *
from OCC.Core.TopOpeBRepDS import *
from OCC.Core.TopoDS import *
from OCC.Core.TopOpeBRepTool import *
from OCC.Core.Geom2dAdaptor import *
from OCC.Core.TCollection import *
from OCC.Core.Bnd import *
from OCC.Core.BRepAdaptor import *
from OCC.Core.TopAbs import *
from OCC.Core.gp import *
from OCC.Core.TopTools import *
from OCC.Core.Geom2d import *
from OCC.Core.Geom import *

TopOpeBRep_PEdgesIntersector = NewType('TopOpeBRep_PEdgesIntersector', TopOpeBRep_EdgesIntersector)
TopOpeBRep_PFacesFiller = NewType('TopOpeBRep_PFacesFiller', TopOpeBRep_FacesFiller)
TopOpeBRep_PFacesIntersector = NewType('TopOpeBRep_PFacesIntersector', TopOpeBRep_FacesIntersector)
TopOpeBRep_PIntRes2d_IntersectionPoint = NewType('TopOpeBRep_PIntRes2d_IntersectionPoint', IntRes2d_IntersectionPoint)
TopOpeBRep_PLineInter = NewType('TopOpeBRep_PLineInter', TopOpeBRep_LineInter)
TopOpeBRep_PPntOn2S = NewType('TopOpeBRep_PPntOn2S', IntSurf_PntOn2S)
TopOpeBRep_PThePointOfIntersection = NewType('TopOpeBRep_PThePointOfIntersection', IntPatch_Point)

class TopOpeBRep_Array1OfLineInter:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> TopOpeBRep_LineInter: ...
    def __setitem__(self, index: int, value: TopOpeBRep_LineInter) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[TopOpeBRep_LineInter]: ...
    def next(self) -> TopOpeBRep_LineInter: ...
    __next__ = next
    def Init(self, theValue: TopOpeBRep_LineInter) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> TopOpeBRep_LineInter: ...
    def Last(self) -> TopOpeBRep_LineInter: ...
    def Value(self, theIndex: int) -> TopOpeBRep_LineInter: ...
    def SetValue(self, theIndex: int, theValue: TopOpeBRep_LineInter) -> None: ...

class TopOpeBRep_Array1OfVPointInter:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> TopOpeBRep_VPointInter: ...
    def __setitem__(self, index: int, value: TopOpeBRep_VPointInter) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[TopOpeBRep_VPointInter]: ...
    def next(self) -> TopOpeBRep_VPointInter: ...
    __next__ = next
    def Init(self, theValue: TopOpeBRep_VPointInter) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> TopOpeBRep_VPointInter: ...
    def Last(self) -> TopOpeBRep_VPointInter: ...
    def Value(self, theIndex: int) -> TopOpeBRep_VPointInter: ...
    def SetValue(self, theIndex: int, theValue: TopOpeBRep_VPointInter) -> None: ...

class TopOpeBRep_ListOfBipoint:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TopOpeBRep_Bipoint: ...
    def Last(self) -> TopOpeBRep_Bipoint: ...
    def Append(self, theItem: TopOpeBRep_Bipoint) -> TopOpeBRep_Bipoint: ...
    def Prepend(self, theItem: TopOpeBRep_Bipoint) -> TopOpeBRep_Bipoint: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TopOpeBRep_Bipoint: ...
    def SetValue(self, theIndex: int, theValue: TopOpeBRep_Bipoint) -> None: ...

class TopOpeBRep_SequenceOfPoint2d:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TopOpeBRep_Point2d: ...
    def Last(self) -> TopOpeBRep_Point2d: ...
    def Length(self) -> int: ...
    def Append(self, theItem: TopOpeBRep_Point2d) -> TopOpeBRep_Point2d: ...
    def Prepend(self, theItem: TopOpeBRep_Point2d) -> TopOpeBRep_Point2d: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TopOpeBRep_Point2d: ...
    def SetValue(self, theIndex: int, theValue: TopOpeBRep_Point2d) -> None: ...

class TopOpeBRep_P2Dstatus(IntEnum):
	TopOpeBRep_P2DUNK: int = ...
	TopOpeBRep_P2DINT: int = ...
	TopOpeBRep_P2DSGF: int = ...
	TopOpeBRep_P2DSGL: int = ...
	TopOpeBRep_P2DNEW: int = ...
TopOpeBRep_P2DUNK = TopOpeBRep_P2Dstatus.TopOpeBRep_P2DUNK
TopOpeBRep_P2DINT = TopOpeBRep_P2Dstatus.TopOpeBRep_P2DINT
TopOpeBRep_P2DSGF = TopOpeBRep_P2Dstatus.TopOpeBRep_P2DSGF
TopOpeBRep_P2DSGL = TopOpeBRep_P2Dstatus.TopOpeBRep_P2DSGL
TopOpeBRep_P2DNEW = TopOpeBRep_P2Dstatus.TopOpeBRep_P2DNEW

class TopOpeBRep_TypeLineCurve(IntEnum):
	TopOpeBRep_ANALYTIC: int = ...
	TopOpeBRep_RESTRICTION: int = ...
	TopOpeBRep_WALKING: int = ...
	TopOpeBRep_LINE: int = ...
	TopOpeBRep_CIRCLE: int = ...
	TopOpeBRep_ELLIPSE: int = ...
	TopOpeBRep_PARABOLA: int = ...
	TopOpeBRep_HYPERBOLA: int = ...
	TopOpeBRep_OTHERTYPE: int = ...
TopOpeBRep_ANALYTIC = TopOpeBRep_TypeLineCurve.TopOpeBRep_ANALYTIC
TopOpeBRep_RESTRICTION = TopOpeBRep_TypeLineCurve.TopOpeBRep_RESTRICTION
TopOpeBRep_WALKING = TopOpeBRep_TypeLineCurve.TopOpeBRep_WALKING
TopOpeBRep_LINE = TopOpeBRep_TypeLineCurve.TopOpeBRep_LINE
TopOpeBRep_CIRCLE = TopOpeBRep_TypeLineCurve.TopOpeBRep_CIRCLE
TopOpeBRep_ELLIPSE = TopOpeBRep_TypeLineCurve.TopOpeBRep_ELLIPSE
TopOpeBRep_PARABOLA = TopOpeBRep_TypeLineCurve.TopOpeBRep_PARABOLA
TopOpeBRep_HYPERBOLA = TopOpeBRep_TypeLineCurve.TopOpeBRep_HYPERBOLA
TopOpeBRep_OTHERTYPE = TopOpeBRep_TypeLineCurve.TopOpeBRep_OTHERTYPE

class topopebrep:
	pass

class TopOpeBRep_Bipoint:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, I1: int, I2: int) -> None: ...
	def I1(self) -> int: ...
	def I2(self) -> int: ...

class TopOpeBRep_DSFiller:
	def __init__(self) -> None: ...
	def ChangeEdgesFiller(self) -> TopOpeBRep_EdgesFiller: ...
	def ChangeFaceEdgeFiller(self) -> TopOpeBRep_FaceEdgeFiller: ...
	def ChangeFacesFiller(self) -> TopOpeBRep_FacesFiller: ...
	def ChangeShapeIntersector(self) -> TopOpeBRep_ShapeIntersector: ...
	def ChangeShapeIntersector2d(self) -> TopOpeBRep_ShapeIntersector2d: ...
	def Checker(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def Complete(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def CompleteDS(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def CompleteDS2d(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def Filter(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def GapFiller(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def Insert(self, S1: TopoDS_Shape, S2: TopoDS_Shape, HDS: TopOpeBRepDS_HDataStructure, orientFORWARD: Optional[bool] = True) -> None: ...
	def Insert1d(self, S1: TopoDS_Shape, S2: TopoDS_Shape, F1: TopoDS_Face, F2: TopoDS_Face, HDS: TopOpeBRepDS_HDataStructure, orientFORWARD: Optional[bool] = False) -> None: ...
	def Insert2d(self, S1: TopoDS_Shape, S2: TopoDS_Shape, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def InsertIntersection(self, S1: TopoDS_Shape, S2: TopoDS_Shape, HDS: TopOpeBRepDS_HDataStructure, orientFORWARD: Optional[bool] = True) -> None: ...
	def InsertIntersection2d(self, S1: TopoDS_Shape, S2: TopoDS_Shape, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def IsContext1d(self, S: TopoDS_Shape) -> bool: ...
	def IsMadeOf1d(self, S: TopoDS_Shape) -> bool: ...
	def PShapeClassifier(self) -> TopOpeBRepTool_PShapeClassifier: ...
	def Reducer(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def RemoveUnsharedGeometry(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...

class TopOpeBRep_EdgesFiller:
	def __init__(self) -> None: ...
	@overload
	def Face(self, I: int, F: TopoDS_Shape) -> None: ...
	@overload
	def Face(self, I: int) -> TopoDS_Shape: ...
	def Insert(self, E1: TopoDS_Shape, E2: TopoDS_Shape, EI: TopOpeBRep_EdgesIntersector, HDS: TopOpeBRepDS_HDataStructure) -> None: ...

class TopOpeBRep_EdgesIntersector:
	def __init__(self) -> None: ...
	def Curve(self, Index: int) -> Geom2dAdaptor_Curve: ...
	@overload
	def Dimension(self, D: int) -> None: ...
	@overload
	def Dimension(self) -> int: ...
	def Dump(self, str: TCollection_AsciiString, ie1: Optional[int] = 0, ie2: Optional[int] = 0) -> None: ...
	def Edge(self, Index: int) -> TopoDS_Shape: ...
	def Face(self, Index: int) -> TopoDS_Shape: ...
	def FacesSameOriented(self) -> bool: ...
	def ForceTolerances(self, Tol1: float, Tol2: float) -> None: ...
	def HasSegment(self) -> bool: ...
	def InitPoint(self, selectkeep: Optional[bool] = True) -> None: ...
	def IsEmpty(self) -> bool: ...
	def MorePoint(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def NbSegments(self) -> int: ...
	def NextPoint(self) -> None: ...
	def Perform(self, E1: TopoDS_Shape, E2: TopoDS_Shape, ReduceSegments: Optional[bool] = True) -> None: ...
	@overload
	def Point(self) -> TopOpeBRep_Point2d: ...
	@overload
	def Point(self, I: int) -> TopOpeBRep_Point2d: ...
	def Points(self) -> TopOpeBRep_SequenceOfPoint2d: ...
	def ReduceSegment(self, P1: TopOpeBRep_Point2d, P2: TopOpeBRep_Point2d, Pn: TopOpeBRep_Point2d) -> bool: ...
	def SameDomain(self) -> bool: ...
	@overload
	def SetFaces(self, F1: TopoDS_Shape, F2: TopoDS_Shape) -> None: ...
	@overload
	def SetFaces(self, F1: TopoDS_Shape, F2: TopoDS_Shape, B1: Bnd_Box, B2: Bnd_Box) -> None: ...
	def Status1(self) -> TopOpeBRep_P2Dstatus: ...
	def Surface(self, Index: int) -> BRepAdaptor_Surface: ...
	def SurfacesSameOriented(self) -> bool: ...
	def ToleranceMax(self) -> float: ...
	def Tolerances(self) -> Tuple[float, float]: ...

class TopOpeBRep_FFDumper(Standard_Transient):
	def __init__(self, PFF: TopOpeBRep_PFacesFiller) -> None: ...
	def DumpDSP(self, VP: TopOpeBRep_VPointInter, GK: TopOpeBRepDS_Kind, G: int, newinDS: bool) -> None: ...
	@overload
	def DumpLine(self, I: int) -> None: ...
	@overload
	def DumpLine(self, L: TopOpeBRep_LineInter) -> None: ...
	@overload
	def DumpVP(self, VP: TopOpeBRep_VPointInter) -> None: ...
	@overload
	def DumpVP(self, VP: TopOpeBRep_VPointInter, ISI: int) -> None: ...
	def ExploreIndex(self, S: TopoDS_Shape, ISI: int) -> int: ...
	def Init(self, PFF: TopOpeBRep_PFacesFiller) -> None: ...
	def PFacesFillerDummy(self) -> TopOpeBRep_PFacesFiller: ...

class TopOpeBRep_FFTransitionTool:
	@staticmethod
	def ProcessEdgeONTransition(VP: TopOpeBRep_VPointInter, Index: int, R: TopoDS_Shape, E: TopoDS_Shape, F: TopoDS_Shape) -> TopOpeBRepDS_Transition: ...
	@staticmethod
	def ProcessEdgeTransition(P: TopOpeBRep_VPointInter, Index: int, LineOrientation: TopAbs_Orientation) -> TopOpeBRepDS_Transition: ...
	@staticmethod
	def ProcessFaceTransition(L: TopOpeBRep_LineInter, Index: int, FaceOrientation: TopAbs_Orientation) -> TopOpeBRepDS_Transition: ...
	@overload
	@staticmethod
	def ProcessLineTransition(P: TopOpeBRep_VPointInter, Index: int, EdgeOrientation: TopAbs_Orientation) -> TopOpeBRepDS_Transition: ...
	@overload
	@staticmethod
	def ProcessLineTransition(P: TopOpeBRep_VPointInter, L: TopOpeBRep_LineInter) -> TopOpeBRepDS_Transition: ...

class TopOpeBRep_FaceEdgeFiller:
	def __init__(self) -> None: ...
	def Insert(self, F: TopoDS_Shape, E: TopoDS_Shape, FEINT: TopOpeBRep_FaceEdgeIntersector, HDS: TopOpeBRepDS_HDataStructure) -> None: ...

class TopOpeBRep_FaceEdgeIntersector:
	def __init__(self) -> None: ...
	def ForceTolerance(self, tol: float) -> None: ...
	def Index(self) -> int: ...
	def InitPoint(self) -> None: ...
	def IsEmpty(self) -> bool: ...
	@overload
	def IsVertex(self, S: TopoDS_Shape, P: gp_Pnt, Tol: float, V: TopoDS_Vertex) -> bool: ...
	@overload
	def IsVertex(self, I: int, V: TopoDS_Vertex) -> bool: ...
	def MorePoint(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def NextPoint(self) -> None: ...
	def Parameter(self) -> float: ...
	def Perform(self, F: TopoDS_Shape, E: TopoDS_Shape) -> None: ...
	def Shape(self, Index: int) -> TopoDS_Shape: ...
	def State(self) -> TopAbs_State: ...
	def Tolerance(self) -> float: ...
	def Transition(self, Index: int, FaceOrientation: TopAbs_Orientation) -> TopOpeBRepDS_Transition: ...
	def UVPoint(self, P: gp_Pnt2d) -> None: ...
	def Value(self) -> gp_Pnt: ...

class TopOpeBRep_FacesFiller:
	def __init__(self) -> None: ...
	def AddShapesLine(self) -> None: ...
	def ChangeDataStructure(self) -> TopOpeBRepDS_DataStructure: ...
	def ChangeFacesIntersector(self) -> TopOpeBRep_FacesIntersector: ...
	def ChangePointClassifier(self) -> TopOpeBRep_PointClassifier: ...
	def CheckLine(self, L: TopOpeBRep_LineInter) -> bool: ...
	@staticmethod
	def EqualpPonR(Lrest: TopOpeBRep_LineInter, VP1: TopOpeBRep_VPointInter, VP2: TopOpeBRep_VPointInter) -> bool: ...
	def Face(self, I: int) -> TopoDS_Face: ...
	@overload
	def FaceFaceTransition(self, L: TopOpeBRep_LineInter, I: int) -> TopOpeBRepDS_Transition: ...
	@overload
	def FaceFaceTransition(self, I: int) -> TopOpeBRepDS_Transition: ...
	def FillLine(self) -> None: ...
	def FillLineVPonR(self) -> None: ...
	def GetESL(self, LES: TopTools_ListOfShape) -> None: ...
	@overload
	def GetFFGeometry(self, DSP: TopOpeBRepDS_Point, K: TopOpeBRepDS_Kind) -> Tuple[bool, int]: ...
	@overload
	def GetFFGeometry(self, VP: TopOpeBRep_VPointInter, K: TopOpeBRepDS_Kind) -> Tuple[bool, int]: ...
	def GetGeometry(self, IT: TopOpeBRepDS_ListIteratorOfListOfInterference, VP: TopOpeBRep_VPointInter, K: TopOpeBRepDS_Kind) -> Tuple[bool, int]: ...
	def GetTraceIndex(self) -> Tuple[int, int]: ...
	def HDataStructure(self) -> TopOpeBRepDS_HDataStructure: ...
	def Insert(self, F1: TopoDS_Shape, F2: TopoDS_Shape, FACINT: TopOpeBRep_FacesIntersector, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	@staticmethod
	def IsVPtransLok(L: TopOpeBRep_LineInter, iVP: int, SI12: int, T: TopOpeBRepDS_Transition) -> bool: ...
	@staticmethod
	def LSameDomainERL(L: TopOpeBRep_LineInter, ERL: TopTools_ListOfShape) -> bool: ...
	@staticmethod
	def Lminmax(L: TopOpeBRep_LineInter) -> Tuple[float, float]: ...
	def LoadLine(self, L: TopOpeBRep_LineInter) -> None: ...
	def MakeGeometry(self, VP: TopOpeBRep_VPointInter, ShapeIndex: int, K: TopOpeBRepDS_Kind) -> int: ...
	def PDataStructureDummy(self) -> TopOpeBRepDS_PDataStructure: ...
	def PFacesIntersectorDummy(self) -> TopOpeBRep_PFacesIntersector: ...
	def PLineInterDummy(self) -> TopOpeBRep_PLineInter: ...
	def PShapeClassifier(self) -> TopOpeBRepTool_PShapeClassifier: ...
	def ProcessLine(self) -> None: ...
	def ProcessRLine(self) -> None: ...
	def ProcessSectionEdges(self) -> None: ...
	def ProcessVPInotonR(self, VPI: TopOpeBRep_VPointInterIterator) -> None: ...
	def ProcessVPIonR(self, VPI: TopOpeBRep_VPointInterIterator, trans1: TopOpeBRepDS_Transition, F1: TopoDS_Shape, ShapeIndex: int) -> None: ...
	def ProcessVPR(self, FF: TopOpeBRep_FacesFiller, VP: TopOpeBRep_VPointInter) -> None: ...
	def ProcessVPnotonR(self, VP: TopOpeBRep_VPointInter) -> None: ...
	def ProcessVPonR(self, VP: TopOpeBRep_VPointInter, trans1: TopOpeBRepDS_Transition, F1: TopoDS_Shape, ShapeIndex: int) -> None: ...
	def ProcessVPonclosingR(self, VP: TopOpeBRep_VPointInter, F1: TopoDS_Shape, ShapeIndex: int, transEdge: TopOpeBRepDS_Transition, PVKind: TopOpeBRepDS_Kind, PVIndex: int, EPIfound: bool, IEPI: TopOpeBRepDS_Interference) -> None: ...
	def ProcessVPondgE(self, VP: TopOpeBRep_VPointInter, ShapeIndex: int, PVKind: TopOpeBRepDS_Kind, IEPI: TopOpeBRepDS_Interference, ICPI: TopOpeBRepDS_Interference) -> Tuple[bool, int, bool, bool]: ...
	def ResetDSC(self) -> None: ...
	def SetPShapeClassifier(self, PSC: TopOpeBRepTool_PShapeClassifier) -> None: ...
	def SetTraceIndex(self, exF1: int, exF2: int) -> None: ...
	def StoreCurveInterference(self, I: TopOpeBRepDS_Interference) -> None: ...
	@staticmethod
	def TransvpOK(L: TopOpeBRep_LineInter, iVP: int, SI: int, isINOUT: bool) -> bool: ...
	@staticmethod
	def VPParamOnER(vp: TopOpeBRep_VPointInter, Lrest: TopOpeBRep_LineInter) -> float: ...
	@overload
	def VP_Position(self, FACINT: TopOpeBRep_FacesIntersector) -> None: ...
	@overload
	def VP_Position(self, L: TopOpeBRep_LineInter) -> None: ...
	@overload
	def VP_Position(self, VP: TopOpeBRep_VPointInter, VPC: TopOpeBRep_VPointInterClassifier) -> None: ...
	def VP_PositionOnL(self, L: TopOpeBRep_LineInter) -> None: ...
	def VP_PositionOnR(self, L: TopOpeBRep_LineInter) -> None: ...

class TopOpeBRep_FacesIntersector:
	def __init__(self) -> None: ...
	def ChangeLine(self, IL: int) -> TopOpeBRep_LineInter: ...
	def CurrentLine(self) -> TopOpeBRep_LineInter: ...
	def CurrentLineIndex(self) -> int: ...
	def Face(self, Index: int) -> TopoDS_Shape: ...
	def ForceTolerances(self, tolarc: float, toltang: float) -> None: ...
	def GetTolerances(self) -> Tuple[float, float]: ...
	def InitLine(self) -> None: ...
	def IsDone(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def IsRestriction(self, E: TopoDS_Shape) -> bool: ...
	def Lines(self) -> TopOpeBRep_HArray1OfLineInter: ...
	def MoreLine(self) -> bool: ...
	def NbLines(self) -> int: ...
	def NextLine(self) -> None: ...
	@overload
	def Perform(self, S1: TopoDS_Shape, S2: TopoDS_Shape) -> None: ...
	@overload
	def Perform(self, S1: TopoDS_Shape, S2: TopoDS_Shape, B1: Bnd_Box, B2: Bnd_Box) -> None: ...
	def PrepareLines(self) -> None: ...
	def Restrictions(self) -> TopTools_IndexedMapOfShape: ...
	def SameDomain(self) -> bool: ...
	def SurfacesSameOriented(self) -> bool: ...

class TopOpeBRep_GeomTool:
	@staticmethod
	def MakeBSpline1fromWALKING2d(L: TopOpeBRep_LineInter, SI: int) -> Geom2d_Curve: ...
	@staticmethod
	def MakeBSpline1fromWALKING3d(L: TopOpeBRep_LineInter) -> Geom_Curve: ...
	@staticmethod
	def MakeCurve(min: float, max: float, L: TopOpeBRep_LineInter, C: Geom_Curve) -> None: ...
	@staticmethod
	def MakeCurves(min: float, max: float, L: TopOpeBRep_LineInter, S1: TopoDS_Shape, S2: TopoDS_Shape, C: TopOpeBRepDS_Curve, PC1: Geom2d_Curve, PC2: Geom2d_Curve) -> None: ...

class TopOpeBRep_Hctxee2d(Standard_Transient):
	def __init__(self) -> None: ...
	def Curve(self, I: int) -> Geom2dAdaptor_Curve: ...
	def Domain(self, I: int) -> IntRes2d_Domain: ...
	def Edge(self, I: int) -> TopoDS_Shape: ...
	def SetEdges(self, E1: TopoDS_Edge, E2: TopoDS_Edge, BAS1: BRepAdaptor_Surface, BAS2: BRepAdaptor_Surface) -> None: ...

class TopOpeBRep_Hctxff2d(Standard_Transient):
	def __init__(self) -> None: ...
	def Face(self, I: int) -> TopoDS_Face: ...
	def FaceSameOrientedWithRef(self, I: int) -> bool: ...
	def FacesSameOriented(self) -> bool: ...
	def GetMaxTolerance(self) -> float: ...
	def GetTolerances(self) -> Tuple[float, float]: ...
	def HSurface(self, I: int) -> BRepAdaptor_HSurface: ...
	def SetFaces(self, F1: TopoDS_Face, F2: TopoDS_Face) -> None: ...
	def SetHSurfaces(self, S1: BRepAdaptor_HSurface, S2: BRepAdaptor_HSurface) -> None: ...
	def SetTolerances(self, Tol1: float, Tol2: float) -> None: ...
	def SurfacesSameOriented(self) -> bool: ...

class TopOpeBRep_LineInter:
	def __init__(self) -> None: ...
	def Arc(self) -> TopoDS_Shape: ...
	def ArcIsEdge(self, I: int) -> bool: ...
	def Bounds(self) -> Tuple[float, float]: ...
	def ChangeVPoint(self, I: int) -> TopOpeBRep_VPointInter: ...
	def ComputeFaceFaceTransition(self) -> None: ...
	@overload
	def Curve(self) -> Geom_Curve: ...
	@overload
	def Curve(self, parmin: float, parmax: float) -> Geom_Curve: ...
	def DumpBipoint(self, B: TopOpeBRep_Bipoint, s1: TCollection_AsciiString, s2: TCollection_AsciiString) -> None: ...
	def DumpType(self) -> None: ...
	def DumpVPoint(self, I: int, s1: TCollection_AsciiString, s2: TCollection_AsciiString) -> None: ...
	def FaceFaceTransition(self, I: int) -> TopOpeBRepDS_Transition: ...
	def GetTraceIndex(self) -> Tuple[int, int]: ...
	def HasFirstPoint(self) -> bool: ...
	def HasLastPoint(self) -> bool: ...
	def HasVInternal(self) -> bool: ...
	def HasVPonR(self) -> bool: ...
	def INL(self) -> bool: ...
	@overload
	def Index(self, I: int) -> None: ...
	@overload
	def Index(self) -> int: ...
	def IsPeriodic(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def LineG(self) -> IntPatch_GLine: ...
	def LineR(self) -> IntPatch_RLine: ...
	def LineW(self) -> IntPatch_WLine: ...
	def NbVPoint(self) -> int: ...
	def NbWPoint(self) -> int: ...
	def OK(self) -> bool: ...
	def Period(self) -> float: ...
	def SetFaces(self, F1: TopoDS_Face, F2: TopoDS_Face) -> None: ...
	def SetHasVPonR(self) -> None: ...
	def SetINL(self) -> None: ...
	def SetIsVClosed(self) -> None: ...
	def SetLine(self, L: IntPatch_Line, S1: BRepAdaptor_Surface, S2: BRepAdaptor_Surface) -> None: ...
	def SetOK(self, B: bool) -> None: ...
	def SetTraceIndex(self, exF1: int, exF2: int) -> None: ...
	def SetVPBounds(self) -> None: ...
	def SituationS1(self) -> IntSurf_Situation: ...
	def SituationS2(self) -> IntSurf_Situation: ...
	def TransitionOnS1(self) -> IntSurf_TypeTrans: ...
	def TransitionOnS2(self) -> IntSurf_TypeTrans: ...
	def TypeLineCurve(self) -> TopOpeBRep_TypeLineCurve: ...
	def VPBounds(self) -> Tuple[int, int, int]: ...
	def VPoint(self, I: int) -> TopOpeBRep_VPointInter: ...
	def WPoint(self, I: int) -> TopOpeBRep_WPointInter: ...

class TopOpeBRep_Point2d:
	def __init__(self) -> None: ...
	def ChangeTransition(self, I: int) -> TopOpeBRepDS_Transition: ...
	def Dump(self, ie1: Optional[int] = 0, ie2: Optional[int] = 0) -> None: ...
	def EdgesConfig(self) -> TopOpeBRepDS_Config: ...
	def HasPint(self) -> bool: ...
	def Hctxee2d(self) -> TopOpeBRep_Hctxee2d: ...
	def Hctxff2d(self) -> TopOpeBRep_Hctxff2d: ...
	def Index(self) -> int: ...
	def IsPointOfSegment(self) -> bool: ...
	def IsVertex(self, I: int) -> bool: ...
	def Keep(self) -> bool: ...
	def Parameter(self, I: int) -> float: ...
	def Pint(self) -> IntRes2d_IntersectionPoint: ...
	def SegmentAncestors(self) -> Tuple[bool, int, int]: ...
	def SetEdgesConfig(self, C: TopOpeBRepDS_Config) -> None: ...
	def SetHctxee2d(self, ee2d: TopOpeBRep_Hctxee2d) -> None: ...
	def SetHctxff2d(self, ff2d: TopOpeBRep_Hctxff2d) -> None: ...
	def SetIndex(self, X: int) -> None: ...
	def SetIsPointOfSegment(self, B: bool) -> None: ...
	def SetIsVertex(self, I: int, B: bool) -> None: ...
	def SetKeep(self, B: bool) -> None: ...
	def SetParameter(self, I: int, P: float) -> None: ...
	def SetPint(self, P: IntRes2d_IntersectionPoint) -> None: ...
	def SetSegmentAncestors(self, IP1: int, IP2: int) -> None: ...
	def SetStatus(self, S: TopOpeBRep_P2Dstatus) -> None: ...
	def SetTolerance(self, T: float) -> None: ...
	def SetTransition(self, I: int, T: TopOpeBRepDS_Transition) -> None: ...
	def SetValue(self, P: gp_Pnt) -> None: ...
	def SetValue2d(self, P: gp_Pnt2d) -> None: ...
	def SetVertex(self, I: int, V: TopoDS_Vertex) -> None: ...
	def Status(self) -> TopOpeBRep_P2Dstatus: ...
	def Tolerance(self) -> float: ...
	def Transition(self, I: int) -> TopOpeBRepDS_Transition: ...
	def Value(self) -> gp_Pnt: ...
	def Value2d(self) -> gp_Pnt2d: ...
	def Vertex(self, I: int) -> TopoDS_Vertex: ...

class TopOpeBRep_PointClassifier:
	def __init__(self) -> None: ...
	def Classify(self, F: TopoDS_Face, P: gp_Pnt2d, Tol: float) -> TopAbs_State: ...
	def Init(self) -> None: ...
	def Load(self, F: TopoDS_Face) -> None: ...
	def State(self) -> TopAbs_State: ...

class TopOpeBRep_PointGeomTool:
	@staticmethod
	def IsEqual(DSP1: TopOpeBRepDS_Point, DSP2: TopOpeBRepDS_Point) -> bool: ...
	@overload
	@staticmethod
	def MakePoint(IP: TopOpeBRep_VPointInter) -> TopOpeBRepDS_Point: ...
	@overload
	@staticmethod
	def MakePoint(P2D: TopOpeBRep_Point2d) -> TopOpeBRepDS_Point: ...
	@overload
	@staticmethod
	def MakePoint(FEI: TopOpeBRep_FaceEdgeIntersector) -> TopOpeBRepDS_Point: ...
	@overload
	@staticmethod
	def MakePoint(S: TopoDS_Shape) -> TopOpeBRepDS_Point: ...

class TopOpeBRep_ShapeIntersector:
	def __init__(self) -> None: ...
	def ChangeEdgesIntersector(self) -> TopOpeBRep_EdgesIntersector: ...
	def ChangeFaceEdgeIntersector(self) -> TopOpeBRep_FaceEdgeIntersector: ...
	def ChangeFacesIntersector(self) -> TopOpeBRep_FacesIntersector: ...
	def CurrentGeomShape(self, Index: int) -> TopoDS_Shape: ...
	def DumpCurrent(self, K: int) -> None: ...
	def GetTolerances(self) -> Tuple[float, float]: ...
	def Index(self, K: int) -> int: ...
	@overload
	def InitIntersection(self, S1: TopoDS_Shape, S2: TopoDS_Shape) -> None: ...
	@overload
	def InitIntersection(self, S1: TopoDS_Shape, S2: TopoDS_Shape, F1: TopoDS_Face, F2: TopoDS_Face) -> None: ...
	def MoreIntersection(self) -> bool: ...
	def NextIntersection(self) -> None: ...
	def RejectedFaces(self, anObj: TopoDS_Shape, aReference: TopoDS_Shape, aListOfShape: TopTools_ListOfShape) -> None: ...
	def Shape(self, Index: int) -> TopoDS_Shape: ...

class TopOpeBRep_ShapeIntersector2d:
	def __init__(self) -> None: ...
	def ChangeEdgesIntersector(self) -> TopOpeBRep_EdgesIntersector: ...
	def CurrentGeomShape(self, Index: int) -> TopoDS_Shape: ...
	def DumpCurrent(self, K: int) -> None: ...
	def Index(self, K: int) -> int: ...
	def InitIntersection(self, S1: TopoDS_Shape, S2: TopoDS_Shape) -> None: ...
	def MoreIntersection(self) -> bool: ...
	def NextIntersection(self) -> None: ...
	def Shape(self, Index: int) -> TopoDS_Shape: ...

class TopOpeBRep_ShapeScanner:
	def __init__(self) -> None: ...
	def AddBoxesMakeCOB(self, S: TopoDS_Shape, TS: TopAbs_ShapeEnum, TA: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> None: ...
	def BoxSort(self) -> TopOpeBRepTool_BoxSort: ...
	def ChangeBoxSort(self) -> TopOpeBRepTool_BoxSort: ...
	def Clear(self) -> None: ...
	def Current(self) -> TopoDS_Shape: ...
	def Index(self) -> int: ...
	@overload
	def Init(self, E: TopoDS_Shape) -> None: ...
	@overload
	def Init(self, X: TopOpeBRepTool_ShapeExplorer) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...

class TopOpeBRep_VPointInter:
	def __init__(self) -> None: ...
	def ArcOnS1(self) -> TopoDS_Shape: ...
	def ArcOnS2(self) -> TopoDS_Shape: ...
	def ChangeKeep(self, keep: bool) -> None: ...
	def Edge(self, I: int) -> TopoDS_Shape: ...
	@overload
	def EdgeON(self, Eon: TopoDS_Shape, Par: float, I: int) -> None: ...
	@overload
	def EdgeON(self, I: int) -> TopoDS_Shape: ...
	def EdgeONParameter(self, I: int) -> float: ...
	def EdgeParameter(self, I: int) -> float: ...
	def EqualpP(self, VP: TopOpeBRep_VPointInter) -> bool: ...
	def GetShapes(self) -> Tuple[int, int]: ...
	@overload
	def Index(self, I: int) -> None: ...
	@overload
	def Index(self) -> int: ...
	def IsInternal(self) -> bool: ...
	def IsMultiple(self) -> bool: ...
	def IsOnDomS1(self) -> bool: ...
	def IsOnDomS2(self) -> bool: ...
	def IsVertex(self, I: int) -> bool: ...
	def IsVertexOnS1(self) -> bool: ...
	def IsVertexOnS2(self) -> bool: ...
	def Keep(self) -> bool: ...
	def PThePointOfIntersectionDummy(self) -> TopOpeBRep_PThePointOfIntersection: ...
	def ParameterOnArc1(self) -> float: ...
	def ParameterOnArc2(self) -> float: ...
	def ParameterOnLine(self) -> float: ...
	def ParametersOnS1(self) -> Tuple[float, float]: ...
	def ParametersOnS2(self) -> Tuple[float, float]: ...
	def ParonE(self, E: TopoDS_Edge) -> Tuple[bool, float]: ...
	def SetPoint(self, P: IntPatch_Point) -> None: ...
	def SetShapes(self, I1: int, I2: int) -> None: ...
	@overload
	def ShapeIndex(self) -> int: ...
	@overload
	def ShapeIndex(self, I: int) -> None: ...
	@overload
	def State(self, I: int) -> TopAbs_State: ...
	@overload
	def State(self, S: TopAbs_State, I: int) -> None: ...
	def SurfaceParameters(self, I: int) -> gp_Pnt2d: ...
	def Tolerance(self) -> float: ...
	def TransitionLineArc1(self) -> IntSurf_Transition: ...
	def TransitionLineArc2(self) -> IntSurf_Transition: ...
	def TransitionOnS1(self) -> IntSurf_Transition: ...
	def TransitionOnS2(self) -> IntSurf_Transition: ...
	def UpdateKeep(self) -> None: ...
	def Value(self) -> gp_Pnt: ...
	def Vertex(self, I: int) -> TopoDS_Shape: ...
	def VertexOnS1(self) -> TopoDS_Shape: ...
	def VertexOnS2(self) -> TopoDS_Shape: ...

class TopOpeBRep_VPointInterClassifier:
	def __init__(self) -> None: ...
	def Edge(self) -> TopoDS_Shape: ...
	def EdgeParameter(self) -> float: ...
	def VPointPosition(self, F: TopoDS_Shape, VP: TopOpeBRep_VPointInter, ShapeIndex: int, PC: TopOpeBRep_PointClassifier, AssumeINON: bool, Tol: float) -> TopAbs_State: ...

class TopOpeBRep_VPointInterIterator:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, LI: TopOpeBRep_LineInter) -> None: ...
	def ChangeCurrentVP(self) -> TopOpeBRep_VPointInter: ...
	def CurrentVP(self) -> TopOpeBRep_VPointInter: ...
	def CurrentVPIndex(self) -> int: ...
	@overload
	def Init(self, LI: TopOpeBRep_LineInter, checkkeep: Optional[bool] = False) -> None: ...
	@overload
	def Init(self) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def PLineInterDummy(self) -> TopOpeBRep_PLineInter: ...

class TopOpeBRep_WPointInter:
	def __init__(self) -> None: ...
	def PPntOn2SDummy(self) -> TopOpeBRep_PPntOn2S: ...
	def Parameters(self) -> Tuple[float, float, float, float]: ...
	def ParametersOnS1(self) -> Tuple[float, float]: ...
	def ParametersOnS2(self) -> Tuple[float, float]: ...
	def Set(self, P: IntSurf_PntOn2S) -> None: ...
	def Value(self) -> gp_Pnt: ...
	def ValueOnS1(self) -> gp_Pnt2d: ...
	def ValueOnS2(self) -> gp_Pnt2d: ...

class TopOpeBRep_WPointInterIterator:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, LI: TopOpeBRep_LineInter) -> None: ...
	def CurrentWP(self) -> TopOpeBRep_WPointInter: ...
	@overload
	def Init(self, LI: TopOpeBRep_LineInter) -> None: ...
	@overload
	def Init(self) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def PLineInterDummy(self) -> TopOpeBRep_PLineInter: ...

#classnotwrapped
class TopOpeBRep_traceSIFF: ...

# harray1 classes

class TopOpeBRep_HArray1OfVPointInter(TopOpeBRep_Array1OfVPointInter, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TopOpeBRep_Array1OfVPointInter: ...


class TopOpeBRep_HArray1OfLineInter(TopOpeBRep_Array1OfLineInter, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TopOpeBRep_Array1OfLineInter: ...

# harray2 classes
# hsequence classes

topopebrep_Print = topopebrep.Print
TopOpeBRep_FFTransitionTool_ProcessEdgeONTransition = TopOpeBRep_FFTransitionTool.ProcessEdgeONTransition
TopOpeBRep_FFTransitionTool_ProcessEdgeTransition = TopOpeBRep_FFTransitionTool.ProcessEdgeTransition
TopOpeBRep_FFTransitionTool_ProcessFaceTransition = TopOpeBRep_FFTransitionTool.ProcessFaceTransition
TopOpeBRep_FFTransitionTool_ProcessLineTransition = TopOpeBRep_FFTransitionTool.ProcessLineTransition
TopOpeBRep_FFTransitionTool_ProcessLineTransition = TopOpeBRep_FFTransitionTool.ProcessLineTransition
TopOpeBRep_FacesFiller_EqualpPonR = TopOpeBRep_FacesFiller.EqualpPonR
TopOpeBRep_FacesFiller_IsVPtransLok = TopOpeBRep_FacesFiller.IsVPtransLok
TopOpeBRep_FacesFiller_LSameDomainERL = TopOpeBRep_FacesFiller.LSameDomainERL
TopOpeBRep_FacesFiller_Lminmax = TopOpeBRep_FacesFiller.Lminmax
TopOpeBRep_FacesFiller_TransvpOK = TopOpeBRep_FacesFiller.TransvpOK
TopOpeBRep_FacesFiller_VPParamOnER = TopOpeBRep_FacesFiller.VPParamOnER
TopOpeBRep_GeomTool_MakeBSpline1fromWALKING2d = TopOpeBRep_GeomTool.MakeBSpline1fromWALKING2d
TopOpeBRep_GeomTool_MakeBSpline1fromWALKING3d = TopOpeBRep_GeomTool.MakeBSpline1fromWALKING3d
TopOpeBRep_GeomTool_MakeCurve = TopOpeBRep_GeomTool.MakeCurve
TopOpeBRep_GeomTool_MakeCurves = TopOpeBRep_GeomTool.MakeCurves
TopOpeBRep_PointGeomTool_IsEqual = TopOpeBRep_PointGeomTool.IsEqual
TopOpeBRep_PointGeomTool_MakePoint = TopOpeBRep_PointGeomTool.MakePoint
TopOpeBRep_PointGeomTool_MakePoint = TopOpeBRep_PointGeomTool.MakePoint
TopOpeBRep_PointGeomTool_MakePoint = TopOpeBRep_PointGeomTool.MakePoint
TopOpeBRep_PointGeomTool_MakePoint = TopOpeBRep_PointGeomTool.MakePoint
